@@ -48,7 +48,7 @@
  * Author:  Adobe Systems Incorporated and MIT X Consortium
  */
 
-#if defined(sun) && !defined(SVR4)
+#if (defined(__sun) || defined(sun)) && !(defined(__SVR4) || defined(SVR4))
 #define memmove(t,f,c) bcopy(f,t,c)
 #endif
 
@@ -332,15 +332,15 @@ DPSCAPConnect(display_name, fullnamep, dpynump,
 	ioctl (fd, FIOSNBIO, &arg);
     }
 #else
-#if defined(sun) && defined(SVR4)
+#if (defined(__sun) || defined(sun)) && (defined(__SVR4) || defined(SVR4))
 #if !defined(_POSIX_C_SOURCE)
     (void) fcntl (fd, F_SETFL, O_NDELAY);
 #else
     (void) fcntl (fd, F_SETFL, O_NONBLOCK);
 #endif
-#else /* sun && SVR4 */
+#else /* __sun && __SVR4 */
     (void) fcntl (fd, F_SETFL, FNDELAY);
-#endif /* sun && SVR4 */
+#endif /* __sun && __SVR4 */
 #endif /* FIOSNBIO */
 
     (void) fcntl (fd, F_SETFD, 1);
