@@ -22,7 +22,7 @@
 
   However Display Ghostscript System depends on GLib. */
 
-/* $Id: gsdpsx.c,v 1.64 2000/01/10 13:27:05 masata-y Exp $ */
+/* $Id: gsdpsx.c,v 1.66 2000/02/05 08:00:44 masata-y Exp $ */
 /* X Windows Display PostScript additions for Ghostscript library */
 
 
@@ -1047,7 +1047,6 @@ dpscap_ConnSetup_display(xCAPConnSetupReq *req)
         dprintf1("setting DISPLAY to '%s'\n", displayname);
       env_pair = g_strdup_printf("DISPLAY=%s", displayname);
       putenv(env_pair);
-      g_free(env_pair);
     }
 }
 
@@ -1572,6 +1571,15 @@ gsdpsx_std_read_process(stream_state *st, stream_cursor_read *ignore_pr,
 	sched_act = SCHED_ACT_YIELD;
       goto forward;
     }
+  else if (ticks_left_value() == (reschedule_interval - 1))
+    {
+      if (0)
+	g_message ("+ ticks: %d cpsid: %d last: %d", 
+		   ticks_left_value (), cpsid, conn->context_state_index_last);
+      gsdpsx_request_context_index(conn->context_state_index_last);
+      sched_act = SCHED_ACT_YIELD;
+      goto forward;
+    }
   else if (cpsid != conn->context_state_index_last)
     {
       dpscap_Notify_pause_check(&conn_info, 0, 0);
@@ -1602,15 +1610,6 @@ gsdpsx_std_read_process(stream_state *st, stream_cursor_read *ignore_pr,
 	  gsdpsx_request_context_index(0);
 	  conn->context_state_index_last = cpsid;
 	}
-      else if (ticks_left_value() == (reschedule_interval - 1))
-	{
-	  if (0)
-	    g_message ("+ ticks: %d cpsid: %d last: %d", 
-		       ticks_left_value (), cpsid, conn->context_state_index_last);
-	  gsdpsx_request_context_index(conn->context_state_index_last);
-	  sched_act = SCHED_ACT_YIELD;
-	  goto forward;
-	}
     }
   else if (newest_cpsid && (conn->ctx_init_parameter.cxid != 0))
     {
