@@ -21,7 +21,7 @@
   does not depend on any other GNU software.
 */
 
-/*$Id: gxdevice.h,v 1.3 1999/04/01 05:31:35 fedor Exp $ */
+/*$Id: gxdevice.h,v 1.4 1999/12/25 06:02:30 masata-y Exp $ */
 /* Definitions for device implementors */
 
 #ifndef gxdevice_INCLUDED
@@ -307,11 +307,6 @@ void gx_device_forward_color_procs(P1(gx_device_forward *));
  */
 void gx_device_copy_params(P2(gx_device *to, const gx_device *from));
 
-/* Open the output file for a device. */
-int gx_device_open_output_file(P5(const gx_device * dev, const char *fname,
-				  bool binary, bool positionable,
-				  FILE ** pfile));
-
 /*
  * Determine whether a given device needs to halftone.  Eventually this
  * should take an imager state as an additional argument.
