@@ -21,7 +21,7 @@
   does not depend on any other GNU software.
 */
 
-/*$Id: interp.c,v 1.5 1999/06/19 06:22:44 masata-y Exp $ */
+/*$Id: interp.c,v 1.8 2000/01/05 17:12:45 masata-y Exp $ */
 /* Ghostscript language interpreter */
 #include "memory_.h"
 #include "string_.h"
@@ -695,6 +695,9 @@ interp(ref * pref /* object to interpret */ , ref * perror_object)
     extern int ticks_left_decrement(void);
     extern int ticks_left_value(void);
     extern int * ticks_left_refer(void);
+    const int gc_ticks_val = -20;
+    int slice_counter = 0;
+    const int slice_counter_max = 10000;
 
     ticks_left_set(gs_interp_time_slice_ticks);
 
@@ -702,7 +705,7 @@ interp(ref * pref /* object to interpret */ , ref * perror_object)
      * If we exceed the VMThreshold, set ticks_left to -1
      * to alert the interpreter that we need to garbage collect.
      */
-    set_gc_signal(ticks_left_refer(), -100);
+    set_gc_signal(ticks_left_refer(), gc_ticks_val);
 
     esfile_clear_cache();
     /*
@@ -1469,12 +1472,17 @@ interp(ref * pref /* object to interpret */ , ref * perror_object)
     ref_assign_inline(iesp, iref);
 #endif /****** ****** ***** */
   slice:			/* It's time to time-slice or garbage collect. */
+    slice_counter++;
     /* iref is not live, so we don't need to do a store_state. */
     osp = iosp;
     esp = iesp;
-    /* If ticks_left <= -100, we need to GC now. */
-    if (ticks_left_value() <= -100) {	/* We need to garbage collect now. */
+    /* If ticks_left <= gc_ticks_val, we need to GC now. */
+    if (ticks_left_value() <= gc_ticks_val ||
+	(slice_counter > slice_counter_max && ticks_left_value() < 0)
+	) {	/* We need to garbage collect now. */
+      /* fprintf(stderr, "run GC\n"); */
 	code = (*idmemory->reclaim) (idmemory, -1);
+	slice_counter = 0;
     } else
 	code = (*gs_interp_time_slice_proc) ();
     ticks_left_set(gs_interp_time_slice_ticks);
