@@ -21,8 +21,11 @@
   does not depend on any other GNU software.
 */
 
-/*$Id: zcontext.c,v 1.6 1999/09/03 17:54:06 masata-y Exp $ */
+/*$Id: zcontext.c,v 1.8 1999/11/30 07:24:08 masata-y Exp $ */
 /* Display PostScript context operators */
+
+#include <limits.h>		/* For INT_MAX */
+
 #include "memory_.h"
 #include "ghost.h"
 #include "gp.h"			/* for usertime */
@@ -53,7 +56,7 @@
 #ifndef DISPLAYGHOSTSCRIPT
 private int reschedule_interval = 100;
 #else 
-private int reschedule_interval = 200;
+int reschedule_interval = 200;
 #endif /* Not def: DISPLAYGHOSTSCRIPT */
 
 
